==> jc-1.4.0.tar.gz: java/awt/image/BufferedImageFilter.h <==
// public class java.awt.image.BufferedImageFilter

// class file dependencies
// @dep_class 45b54e56d48d5b7f java_awt_image_BufferedImageFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ImageFilter

#include "java/awt/image/ImageFilter.h"

#ifndef _JC_java_awt_image_BufferedImageFilter_H_
#define _JC_java_awt_image_BufferedImageFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_BufferedImageOp$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferedImageFilter$sub_refs	_jc_java_awt_image_BufferedImageFilter$sub_refs;
typedef struct _jc_java_awt_image_BufferedImageFilter$sub_nonrefs	_jc_java_awt_image_BufferedImageFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferedImageFilter$refs	_jc_java_awt_image_BufferedImageFilter$refs;
typedef struct _jc_java_awt_image_BufferedImageFilter$nonrefs	_jc_java_awt_image_BufferedImageFilter$nonrefs;
typedef struct _jc_java_awt_image_BufferedImageFilter$object	_jc_java_awt_image_BufferedImageFilter$object;

typedef const struct _jc_java_awt_image_BufferedImageFilter$vmethods	_jc_java_awt_image_BufferedImageFilter$vmethods;
typedef const struct _jc_java_awt_image_BufferedImageFilter$vtable	_jc_java_awt_image_BufferedImageFilter$vtable;
typedef const struct _jc_java_awt_image_BufferedImageFilter$vtype	_jc_java_awt_image_BufferedImageFilter$vtype;

// Constructors
extern void _jc_java_awt_image_BufferedImageFilter$method$_init$3334ddf4655f76da(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_awt_image_BufferedImageFilter$method$getBufferedImageOp$1e0afb44d9fcf044(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *);
extern void _jc_java_awt_image_BufferedImageFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_awt_image_BufferedImageFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$getBufferedImageOp$1e0afb44d9fcf044;
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$setPixels$07377c973c113c2c;

// Virtual methods structure
struct _jc_java_awt_image_BufferedImageFilter$vmethods {
	struct _jc_object	*(*getBufferedImageOp$1e0afb44d9fcf044)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *);
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);
};

// Vtable
struct _jc_java_awt_image_BufferedImageFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_BufferedImageFilter$vmethods	java_awt_image_BufferedImageFilter;
};

// Vtype
struct _jc_java_awt_image_BufferedImageFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferedImageFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImageFilter$sub_refs {
	struct _jc_object	*op;
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferedImageFilter$refs {
    _jc_java_awt_image_BufferedImageFilter$sub_refs	java_awt_image_BufferedImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImageFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferedImageFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_BufferedImageFilter$sub_nonrefs	java_awt_image_BufferedImageFilter;
};

// Object instance structure
struct _jc_java_awt_image_BufferedImageFilter$object {
	_jc_java_awt_image_BufferedImageFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferedImageFilter$vtype	*vtype;
	_jc_java_awt_image_BufferedImageFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferedImageFilter$vtype _jc_java_awt_image_BufferedImageFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferedImageFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferedImageFilter$class_object;

#endif	/* _JC_java_awt_image_BufferedImageFilter_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/BufferedImageFilter.h <==
// public class java.awt.image.BufferedImageFilter

// class file dependencies
// @dep_class 45b54e56d48d5b7f java_awt_image_BufferedImageFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ImageFilter

#include "java/awt/image/ImageFilter.h"

#ifndef _JC_java_awt_image_BufferedImageFilter_H_
#define _JC_java_awt_image_BufferedImageFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_BufferedImageOp$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferedImageFilter$sub_refs	_jc_java_awt_image_BufferedImageFilter$sub_refs;
typedef struct _jc_java_awt_image_BufferedImageFilter$sub_nonrefs	_jc_java_awt_image_BufferedImageFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferedImageFilter$refs	_jc_java_awt_image_BufferedImageFilter$refs;
typedef struct _jc_java_awt_image_BufferedImageFilter$nonrefs	_jc_java_awt_image_BufferedImageFilter$nonrefs;
typedef struct _jc_java_awt_image_BufferedImageFilter$object	_jc_java_awt_image_BufferedImageFilter$object;

typedef const struct _jc_java_awt_image_BufferedImageFilter$vmethods	_jc_java_awt_image_BufferedImageFilter$vmethods;
typedef const struct _jc_java_awt_image_BufferedImageFilter$vtable	_jc_java_awt_image_BufferedImageFilter$vtable;
typedef const struct _jc_java_awt_image_BufferedImageFilter$vtype	_jc_java_awt_image_BufferedImageFilter$vtype;

// Constructors
extern void _jc_java_awt_image_BufferedImageFilter$method$_init$3334ddf4655f76da(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_image_BufferedImageFilter$method$getBufferedImageOp$1e0afb44d9fcf044(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImageFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImageFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$getBufferedImageOp$1e0afb44d9fcf044;
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_BufferedImageFilter$method_info$setPixels$07377c973c113c2c;

// Virtual methods structure
struct _jc_java_awt_image_BufferedImageFilter$vmethods {
	struct _jc_object	*(*getBufferedImageOp$1e0afb44d9fcf044)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *) _JC_JCNI_ATTR;
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_BufferedImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_BufferedImageFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_BufferedImageFilter$vmethods	java_awt_image_BufferedImageFilter;
};

// Vtype
struct _jc_java_awt_image_BufferedImageFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferedImageFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImageFilter$sub_refs {
	struct _jc_object	*op;
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferedImageFilter$refs {
    _jc_java_awt_image_BufferedImageFilter$sub_refs	java_awt_image_BufferedImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImageFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferedImageFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_BufferedImageFilter$sub_nonrefs	java_awt_image_BufferedImageFilter;
};

// Object instance structure
struct _jc_java_awt_image_BufferedImageFilter$object {
	_jc_java_awt_image_BufferedImageFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferedImageFilter$vtype	*vtype;
	_jc_java_awt_image_BufferedImageFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferedImageFilter$vtype _jc_java_awt_image_BufferedImageFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferedImageFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferedImageFilter$class_object;

#endif	/* _JC_java_awt_image_BufferedImageFilter_H_ */
